=======================================================================
``psyclone.domain.nemo.transformations.nemo_allarrayaccess2loop_trans``
=======================================================================

.. automodule:: psyclone.domain.nemo.transformations.nemo_allarrayaccess2loop_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.nemo.transformations.nemo_allarrayaccess2loop_trans


Classes
=======

- :py:class:`NemoAllArrayAccess2LoopTrans`:
  Provides a transformation from a PSyIR Assignment containing


.. autoclass:: NemoAllArrayAccess2LoopTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: NemoAllArrayAccess2LoopTrans
      :parts: 1
